@@ -46,18 +46,6 @@ fmi2LastSuccessfulTime = 2
 fmi2Terminated         = 3
 
 
-def allocateMemory(nobj, size):
-    return calloc(nobj, size)
-
-
-def freeMemory(obj):
-    free(obj)
-
-
-def stepFinished(componentEnvironment, status):
-    pass
-
-
 class fmi2CallbackFunctions(Structure):
 
     _fields_ = [('logger',               fmi2CallbackLoggerTYPE),
@@ -77,6 +65,18 @@ class fmi2EventInfo(Structure):
                 ('nextEventTime',                     fmi2Real)]
 
 
+defaultCallbacks                = fmi2CallbackFunctions()
+defaultCallbacks.logger         = fmi2CallbackLoggerTYPE(printLogMessage)
+defaultCallbacks.allocateMemory = fmi2CallbackAllocateMemoryTYPE(calloc)
+defaultCallbacks.freeMemory     = fmi2CallbackFreeMemoryTYPE(free)
+
+try:
+    from .logging import addLoggerProxy
+    addLoggerProxy(byref(defaultCallbacks))
+except Exception as e:
+    print(f"Failed to add logger proxy function. {e}")
+
+
 class _FMU2(_FMU):
     """ Base class for FMI 2.0 FMUs """
 
@@ -240,13 +240,7 @@ class _FMU2(_FMU):
         kind = fmi2ModelExchange if isinstance(self, FMU2Model) else fmi2CoSimulation
         resourceLocation = pathlib.Path(self.unzipDirectory, 'resources').as_uri()
 
-        if callbacks is None:
-            callbacks = fmi2CallbackFunctions()
-            callbacks.logger = fmi2CallbackLoggerTYPE(printLogMessage)
-            callbacks.allocateMemory = fmi2CallbackAllocateMemoryTYPE(allocateMemory)
-            callbacks.freeMemory = fmi2CallbackFreeMemoryTYPE(freeMemory)
-
-        self.callbacks = callbacks
+        self.callbacks = defaultCallbacks if callbacks is None else callbacks
 
         self.component = self.fmi2Instantiate(self.instanceName.encode('utf-8'),
                                               kind,
@@ -345,12 +339,18 @@ class _FMU2(_FMU):
         self.fmi2GetFMUstate(self.component, byref(state))
         return state
 
+    getFMUState = getFMUstate  # alias for the FMI 3.0 name
+
     def setFMUstate(self, state):
         self.fmi2SetFMUstate(self.component, state)
 
+    setFMUState = setFMUstate
+
     def freeFMUstate(self, state):
         self.fmi2FreeFMUstate(self.component, byref(state))
 
+    freeFMUState = freeFMUstate
+
     def serializeFMUstate(self, state):
         """ Serialize an FMU state
 
@@ -367,6 +367,8 @@ class _FMU2(_FMU):
         self.fmi2SerializeFMUstate(self.component, state, serializedState, size)
         return serializedState.raw
 
+    serializeFMUState = serializeFMUstate
+
     def deSerializeFMUstate(self, serializedState, state=None):
         """ De-serialize an FMU state
 
@@ -383,6 +385,8 @@ class _FMU2(_FMU):
         self.fmi2DeSerializeFMUstate(self.component, buffer, len(buffer), byref(state))
         return state
 
+    deserializeFMUState = deSerializeFMUstate
+
     # Getting partial derivatives
 
     def getDirectionalDerivative(self, vUnknown_ref, vKnown_ref, dvKnown):
