@@ -230,7 +230,7 @@ class ScalarVariable(object):
     priority = attrib(type=int, default=None, repr=False)
 
     intervalVariability = attrib(type=str, default=None, repr=False)
-    "One of 'constant', 'fixed', 'calculated', 'tunable', 'changing', 'countdown', 'triggered' or None"
+    "One of 'constant', 'fixed', 'tunable', 'changing', 'countdown', 'triggered' or None"
 
     intervalDecimal = attrib(type=float, default=None, repr=False)
 
@@ -673,9 +673,11 @@ def read_model_description(filename: Union[str, IO], validate: bool = True, vali
 
         sv.type = value.tag
 
-        if variable.tag == 'String':
-            # handle <Start> element of String variables in FMI 3
-            sv.start = variable.find('Start').get('value')
+        if variable.tag in {'Binary', 'String'}:
+            # handle <Start> element of Binary and String variables in FMI 3
+            start = variable.find('Start')
+            if start is not None:
+                sv.start = start.get('value')
         else:
             sv.start = value.get('start')
 
